==> ruby-web-common-1.5.3.tgz: package/src/components/slider_page/slide/index.tsx <==
// node modules
import React, { FC, useEffect, useState } from 'react';
import parser from 'html-react-parser';

// local files
import { Typography } from "../../typography";
import { TextNormalizer } from "../../parser";

// local files
import { useStyles } from "./styles";

export type SliderProps = {
    image?: boolean;
    value: string;
    delay?: number;
    color?: string;
    variant?: 'body1' | 'h3' | 'h2' | 'h4' | 'label' |  'body2' | 'title' | 'bigTitle'
}

interface SlideContentProps {
    handleNext: () => void;
    content: SliderProps;
    color?: string;
    rootSlideClass?: string;
}

const waiting = (delay: number) => {
    return new Promise(resolve => {
        setTimeout(resolve, delay)
    })
}

const ELEMENT_DELAY = 3000;
const TIMEOUT_DELAY = 1800;

export const Slide: FC<SlideContentProps> = ({ handleNext, content, rootSlideClass, color }) => {
    const { slideClass, slideShowed, typ, imageWrapper } = useStyles();
    const [activeClass, setActiveClass] = useState(false);

    useEffect(() => {
        const { delay } = content;

        waiting(delay || ELEMENT_DELAY).then(() => {
            setActiveClass(false);
            setTimeout(handleNext, TIMEOUT_DELAY)
        });

        setActiveClass(true);
    }, [content]);

    const className = `${slideClass} ${rootSlideClass} ${activeClass ? slideShowed : ''}`;

    return (
        <div className={className}>
            {content.image
                ? <div className={imageWrapper}><img src={content.value} alt=""/></div>
                : (
                    <Typography
                        style={{ color: content.color || color || null }}
                        variant={content.variant || 'bigTitle'}
                        className={typ}
                    >
                        {parser(TextNormalizer(
                            content.value,
                            {
                                brChanger: true,
                                localStorageMode: true
                            }
                        ))}
                    </Typography>
                )
            }

        </div>
    )
};

==> ruby-web-common-2.5.5.tgz: package/src/components/slider_page/slide/index.tsx <==
// node modules
import React, { FC, useEffect, useState } from 'react';
import parser from 'html-react-parser';

// local files
import { Typography } from "../../typography";
import { TextNormalizer } from "../../parser";

// local files
import { useStyles } from "./styles";

export type SliderProps = {
    image?: boolean;
    value: string | JSX.Element;
    delay?: number;
    color?: string;
    variant?: 'body1' | 'h3' | 'h2' | 'h4' | 'label' |  'body2' | 'title' | 'bigTitle'
}

interface SlideContentProps {
    handleNext: () => void;
    content: SliderProps;
    color?: string;
    rootSlideClass?: string;
}

const waiting = (delay: number) => {
    return new Promise(resolve => {
        setTimeout(resolve, delay)
    })
}

const ELEMENT_DELAY = 3000;
const TIMEOUT_DELAY = 1800;

export const Slide: FC<SlideContentProps> = ({ handleNext, content, rootSlideClass, color }) => {
    const { slideClass, slideShowed, typ, imageWrapper } = useStyles();
    const [activeClass, setActiveClass] = useState(false);

    useEffect(() => {
        const { delay } = content;

        waiting(delay || ELEMENT_DELAY).then(() => {
            setActiveClass(false);
            setTimeout(handleNext, TIMEOUT_DELAY)
        });

        setActiveClass(true);
    }, [content]);

    const className = `${slideClass} ${rootSlideClass} ${activeClass ? slideShowed : ''}`;

    return (
        <div className={className}>
            {typeof content.value !== 'string'
                ? <div className={imageWrapper}>{content.value}</div>
                : (
                    <Typography
                        style={{ color: content.color || color || null }}
                        variant={content.variant || 'bigTitle'}
                        className={typ}
                    >
                        {parser(TextNormalizer(
                            content.value,
                            {
                                brChanger: true,
                                localStorageMode: true
                            }
                        ))}
                    </Typography>
                )
            }

        </div>
    )
};
